## 3. FFdataAppend.R
## Fracfocus database - append geochemical/parameter data to each distinct well in FFU
## Andrew Sumner 2-Jan-2020

## These are some packages I used - install as needed
# install.packages('maps')
# install.packages('maptools')
library(maps)
library(maptools)

# Have USGS Nationa Produced Waters Geochemical Database downloaded in working folder
# Available here https://www.sciencebase.gov/catalog/item/59d25d63e4b05fe04cc235f9, download "USGSPWDBv2.3n.csv"
usgs <- read.csv('USGSPWDBv2.3n.csv',as.is=T)

# Have NGDS Well temperature data downloaded as well.
# Available here http://geothermal.smu.edu/static/DownloadFilesButtonPage.htm, download "Aggregated Well Data" csv
ngds <- read.csv("core.surface_site_county_state_materialized_view.csv",as.is=T)
ngds <- ngds[!is.na(ngds$bht),] # reject data without temperatures

wells <- FFU # I defaulted to making "wells" all of FracFocus, but you could make it a subset
## Now implement append functions, adding on well condition values successively
wells[,c('basin','Cl_m','Cl_sd')] <- Add_basin_Cl(wells,usgs) # basin name, Cl (USGS)
wells[,c('pH_m','pH_sd')] <- Add_pH(wells,usgs) # pH data (USGS)
# ^ this should get you most pH data, but you can fill in N/A's with basin averages, similar to Br and I
wells[,c('Br_m','Br_sd','I_m','I_sd')] <- Add_Br_I(wells,usgs) # Br, I data from Basin (USGS)
wells[,c('Temp_m','Temp_sd')] <- Add_Temp(wells,ngds) # Temperature data from NGDS (NGDS)

## now record it, because that probably took a while. 
write.csv(wells, "wells_appended.csv", row.names=F)
## now you can read in the saved csv whenever you want!